@@ -5,7 +5,18 @@ import convertible
 from IPy import IP
 from syncloud.app import logger
 from syncloud.insider.config import Service
+from syncloud.tools import id
 
+import commands
+import re
+
+def ip_addresses():
+    output = commands.getoutput("/sbin/ifconfig")
+    ip_find = re.finditer(r'inet addr:(\S+)', output)
+    return [ip_search.group(1) for ip_search in ip_find]
+
+def ip_address():
+    return next((address for address in ip_addresses() if address != '127.0.0.1'), None)
 
 class ServiceUrls:
     def __init__(self, device_domain, service, mapping):
@@ -36,9 +47,17 @@ class Dns:
             raise Exception(error.message)
 
     def acquire(self, email, password, user_domain):
-        data = {'email': email, 'password': password, 'user_domain': user_domain}
+        device_id = id.id()
+        data = {
+            'email': email,
+            'password': password,
+            'user_domain': user_domain,
+            'device_mac_address': device_id.mac_address,
+            'device_name': device_id.name,
+            'device_title': device_id.title,
+        }
         url = urljoin(self.api_url, "/domain/acquire")
-        response = requests.post(url, data)
+        response = requests.post(url, convertible.to_json(data))
         self.check_http_error(response)
         domain = convertible.from_json(response.text)
         self.domain_config.save(domain)
@@ -86,29 +105,42 @@ class Dns:
         services = self.service_config.load()
         domain = self.domain_config.load()
         if not domain:
-            raise Exception("no token saved, need to call set_dns or get_dns_token first")
-
-        external_ip = self.port_mapper.external_ip()
-        if not external_ip:
-            self.logger.warn("unable to get external ip")
-        else:
-            if IP(external_ip).iptype() != 'PUBLIC':
-                external_ip = None
-                self.logger.warn("external ip is not public")
+            raise Exception("No token saved, need to call set_dns or get_dns_token first")
 
+        services_data = []
         for service in services:
             mapping = self.port_mapper.get(service.port)
             if mapping:
                 service.port = mapping.external_port
-            else:
-                services.remove(service)
+                service_data = dict(
+                    name=service.name,
+                    protocol=service.protocol,
+                    type=service.type,
+                    url=service.url,
+                    port=mapping.external_port,
+                    local_port=mapping.local_port
+                )
+                services_data.append(service_data)
+
+        local_ip = ip_address()
+
+        if not local_ip:
+            raise(Exception("Can't get local ip address"))
+
+        data = {'token': domain.update_token, 'local_ip': ip_address(), 'services': services_data}
+
+        external_ip = self.port_mapper.external_ip()
+        if not external_ip:
+            self.logger.warn("Unable to get external ip")
+        else:
+            if IP(external_ip).iptype() != 'PUBLIC':
+                external_ip = None
+                self.logger.warn("External ip is not public")
 
-        data = {'token': domain.update_token, 'services': services}
         if external_ip:
             data['ip'] = external_ip
         else:
-            self.logger.warn("will try server side client ip detection")
-
+            self.logger.warn("Will try server side client ip detection")
 
         url = urljoin(self.api_url, "/domain/update")
 
